eacl.datomic.db

Datomic-only entity, schema-definition, and ordered adjacency operations.

Datomic-only entity, schema-definition, and ordered adjacency operations.
raw docstring

all-permission-nodesclj

(all-permission-nodes db)

avet-tuple-prefixclj

(avet-tuple-prefix database attribute prefix)

All stored endpoint rows in one typed Relation partition, including qualifiers.

All stored endpoint rows in one typed Relation partition, including qualifiers.
raw docstring

direct-edgeclj

(direct-edge db subject-type subject-id relation-id resource-type resource-id)

Stored compact edge or nil, prior to request qualification.

Stored compact edge or nil, prior to request qualification.
raw docstring

direct-match?clj

(direct-match? db subject-type subject-id relation-id resource-type resource-id)

entity-dataclj

(entity-data database eid)

entity-factsclj

(entity-facts database eid)

find-permission-defsclj

(find-permission-defs db resource-type permission-name)

find-relation-defclj

(find-relation-def db resource-type relation-name)

global-relationship-identity-datomsclj

(global-relationship-identity-datoms db attr value)

object-eidclj

(object-eid db object-id)

relation-datomsclj

(relation-datoms db resource-type relation-name)

relationship-identity-datomsclj

(relationship-identity-datoms db entity attr value)

One owner/attribute/identity seek, retaining exact qualifier variants.

One owner/attribute/identity seek, retaining exact qualifier variants.
raw docstring

resource->subjectsclj

(resource->subjects db
                    resource-type
                    resource-id
                    relation-id
                    subject-type
                    cursor-or-options)

schema-versionclj

(schema-version db)

subject->resourcesclj

(subject->resources db
                    subject-type
                    subject-id
                    relation-id
                    resource-type
                    cursor-or-options)

cljdoc builds & hosts documentation for Clojure/Script libraries